@@ -23,3 +23,7 @@ extern PyObject ** hspy_getexc();
 extern int hspy_list_check(PyObject *o);
 extern int hspy_tuple_check(PyObject *o);
 extern PyObject *hspy_none(void);
+
+/* These are now macros */
+extern PyObject *glue_PyMapping_Keys(PyObject *o);
+extern PyObject *glue_PyMapping_Items(PyObject *o);
