@@ -18,14 +18,14 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 module AnyDBMtest(mf, generic_persist_test, generic_test, tests) where
 import Test.HUnit
-import MissingH.List
-import MissingH.IO.HVFS
-import MissingH.IO.HVFS.InstanceHelpers
-import MissingH.AnyDBM
-import MissingH.AnyDBM.StringDBM
-import MissingH.AnyDBM.FiniteMapDBM
+import Data.List.Utils
+import System.IO.HVFS
+import System.IO.HVFS.InstanceHelpers
+import Database.AnyDBM
+import Database.AnyDBM.StringDBM
+import Database.AnyDBM.MapDBM
 import System.Directory
-import MissingH.IO.HVFS.Utils
+import System.IO.HVFS.Utils
 import Data.HashTable
 import Data.List(sort)
 import Control.Exception(finally)
@@ -102,8 +102,8 @@ generic_persist_test initfunc openfunc =
 test_hashtable = generic_test (return ())
                   (\_ -> ((new (==) hashString)::IO (HashTable String String)))
 
-test_finitemap = generic_test (return ())
-                  (\_ -> newFiniteMapDBM)
+test_map = generic_test (return ())
+           (\_ -> newMapDBM)
 test_stringdbm = generic_persist_test (return SystemFS)
                    (\f -> openStringVDBM f "testtmp/StringDBM" ReadWriteMode)
                  ++
@@ -112,7 +112,7 @@ test_stringdbm = generic_persist_test (return SystemFS)
 
 tests = TestList [TestLabel "HashTable" (TestList test_hashtable),
                   TestLabel "StringDBM" (TestList test_stringdbm),
-                  TestLabel "FiniteMap" (TestList test_finitemap)
+                  TestLabel "Map" (TestList test_map)
                  ]
 
 
